@@ -39,15 +39,34 @@ def test_deep_inheritance():
 
     manager = DIManager(firstName='Project', lastName='Manager',
         position='Project Manager')
-    employee = DIEmployee(firstName='Project', lastName='Leader',
-        position='Project leader', manager=manager)
-    person = DIPerson(firstName='Oneof', lastName='Authors', manager=manager)
+    manager_id = manager.id
+    employee_id = DIEmployee(firstName='Project', lastName='Leader',
+        position='Project leader', manager=manager).id
+    person_id = DIPerson(firstName='Oneof', lastName='Authors',
+        manager=manager).id
+
+    cache = getConnection().cache
+    cache.clear()
 
     managers = list(DIManager.select())
     assert len(managers) == 1
+    cache.clear()
 
     employees = list(DIEmployee.select())
     assert len(employees) == 2
+    cache.clear()
 
     persons = list(DIPerson.select())
     assert len(persons) == 3
+    cache.clear()
+
+    person = DIPerson.get(employee_id)
+    assert isinstance(person, DIEmployee)
+
+    person = DIPerson.get(manager_id)
+    assert isinstance(person, DIEmployee)
+    assert isinstance(person, DIManager)
+    cache.clear()
+
+    person = DIEmployee.get(manager_id)
+    assert isinstance(person, DIManager)
