@@ -1,6 +1,7 @@
+from sqlobject import col
 from sqlobject.dbconnection import DBAPI
 from sqlobject.dberrors import *
-from sqlobject import col
+from sqlobject.main import deprecated
 MySQLdb = None
 
 class ErrorMessage(str):
@@ -17,7 +18,7 @@ class MySQLConnection(DBAPI):
     dbName = 'mysql'
     schemes = [dbName]
 
-    def __init__(self, db, user, password='', host='localhost', port=None, **kw):
+    def __init__(self, db, user, password='', host='localhost', port=0, **kw):
         global MySQLdb
         if MySQLdb is None:
             import MySQLdb, MySQLdb.constants.CR, MySQLdb.constants.ER
@@ -28,12 +29,8 @@ class MySQLConnection(DBAPI):
         self.user = user
         self.password = password
         self.kw = {}
-        if MySQLdb.version_info[:3] >= (1, 2, 1):
-            self.need_unicode = True
-        else:
-            self.need_unicode = False
         for key in ("unix_socket", "init_command",
-                "read_default_file", "read_default_group"):
+                "read_default_file", "read_default_group", "conv"):
             if key in kw:
                 self.kw[key] = col.popKey(kw, key)
         for key in ("connect_timeout", "compress", "named_pipe", "use_unicode",
@@ -45,9 +42,8 @@ class MySQLConnection(DBAPI):
         else:
             self.dbEncoding = None
         if "sqlobject_encoding" in kw:
-            self.encoding = col.popKey(kw, "sqlobject_encoding")
-        else:
-            self.encoding = 'ascii'
+            del kw["sqlobject_encoding"]
+            deprecated("sqlobject_encoding is deprecated and no longer used.")
         DBAPI.__init__(self, **kw)
 
     def connectionFromURI(cls, uri):
@@ -79,12 +75,12 @@ class MySQLConnection(DBAPI):
         if hasattr(conn, 'autocommit'):
             conn.autocommit(bool(self.autoCommit))
 
-        if self.dbEncoding:
+        if dbEncoding:
             if hasattr(conn, 'set_character_set'): # MySQLdb 1.2.1 and later
-                conn.set_character_set(self.dbEncoding)
+                conn.set_character_set(dbEncoding)
             else: # pre MySQLdb 1.2.1
                 # works along with monkeypatching code above
-                conn.query("SET NAMES %s" % self.dbEncoding)
+                conn.query("SET NAMES %s" % dbEncoding)
 
         return conn
 
@@ -107,10 +103,6 @@ class MySQLConnection(DBAPI):
         # done by calling ping(True) on the connection.
         for count in range(3):
             try:
-                # For MySQLdb 1.2.1 and later, we go
-                # encoding->unicode->charset (in the mysql db)
-                if self.need_unicode and not isinstance(query, unicode):
-                    query = unicode(query, self.encoding)
                 return cursor.execute(query)
             except MySQLdb.OperationalError, e:
                 if e.args[0] in (MySQLdb.constants.CR.SERVER_GONE_ERROR, MySQLdb.constants.CR.SERVER_LOST):
@@ -204,10 +196,8 @@ class MySQLConnection(DBAPI):
                    (tableName,
                     column.mysqlCreateSQL()))
 
-    def delColumn(self, tableName, column):
-        self.query('ALTER TABLE %s DROP COLUMN %s' %
-                   (tableName,
-                    column.dbName))
+    def delColumn(self, sqlmeta, column):
+        self.query('ALTER TABLE %s DROP COLUMN %s' % (sqlmeta.table, column.dbName))
 
     def columnsFromSchema(self, tableName, soClass):
         colData = self.queryAll("SHOW COLUMNS FROM %s"
@@ -222,9 +212,18 @@ class MySQLConnection(DBAPI):
                 if self.dbEncoding: kw['dbEncoding'] = self.dbEncoding
             kw['name'] = soClass.sqlmeta.style.dbColumnToPythonAttr(field)
             kw['dbName'] = field
-            kw['notNone'] = not nullAllowed
+
+            # Since MySQL 5.0, 'NO' is returned in the NULL column (SQLObject expected '')
+            kw['notNone'] = (nullAllowed.upper() != 'YES' and True or False)
+
             if default and t.startswith('int'):
                 kw['default'] = int(default)
+            elif default and t.startswith('float'):
+                kw['default'] = float(default)
+            elif default == 'CURRENT_TIMESTAMP' and t == 'timestamp':
+                kw['default'] = None
+            elif default and colClass is col.BoolCol:
+                kw['default'] = int(default) and True or False
             else:
                 kw['default'] = default
             # @@ skip key...
@@ -235,12 +234,22 @@ class MySQLConnection(DBAPI):
     def guessClass(self, t):
         if t.startswith('int'):
             return col.IntCol, {}
+        elif t.startswith('enum'):
+            values = []
+            for i in t[5:-1].split(','): # take the enum() off and split
+                values.append(i[1:-1]) # remove the surrounding \'
+            return col.EnumCol, {'enumValues': values}
+        elif t.startswith('double'):
+            return col.FloatCol, {}
         elif t.startswith('varchar'):
+            colType = col.StringCol
+            if self.kw.get('use_unicode', False):
+                colType = col.UnicodeCol
             if t.endswith('binary'):
-                return col.StringCol, {'length': int(t[8:-8]),
+                return colType, {'length': int(t[8:-8]),
                                        'char_binary': True}
             else:
-                return col.StringCol, {'length': int(t[8:-1])}
+                return colType, {'length': int(t[8:-1])}
         elif t.startswith('char'):
             if t.endswith('binary'):
                 return col.StringCol, {'length': int(t[5:-8]),
@@ -251,6 +260,12 @@ class MySQLConnection(DBAPI):
                                        'varchar': False}
         elif t.startswith('datetime'):
             return col.DateTimeCol, {}
+        elif t.startswith('date'):
+            return col.DateCol, {}
+        elif t.startswith('time'):
+            return col.TimeCol, {}
+        elif t.startswith('timestamp'):
+            return col.TimestampCol, {}
         elif t.startswith('bool'):
             return col.BoolCol, {}
         elif t.startswith('tinyblob'):
