@@ -1,6 +1,8 @@
 from sqlobject import *
 from sqlobject.tests.dbtest import *
 from sqlobject import classregistry
+from py.test import raises
+
 try:
     from datetime import datetime
     now = datetime.now
@@ -47,7 +49,7 @@ class TestPeople:
         Person.sqlmeta.delColumn(nickname, changeSchema=True)
 
     def test_dynamicJoin(self):
-        col = KeyCol('personID', foreignKey='Person')
+        col = KeyCol('person', foreignKey='Person')
         Phone.sqlmeta.addColumn(col, changeSchema=True)
         join = MultipleJoin('Phone')
         Person.sqlmeta.addJoin(join)
@@ -62,6 +64,17 @@ class TestPeople:
         Phone.sqlmeta.delColumn(col, changeSchema=True)
         Person.sqlmeta.delJoin(join)
 
+    def _test_collidingName(self):
+        class CollidingName(SQLObject):
+            expire = StringCol()
+
+    def test_collidingName(self):
+        raises(AssertionError, Person.sqlmeta.addColumn, StringCol(name="name"))
+        raises(AssertionError, Person.sqlmeta.addColumn, StringCol(name="_init"))
+        raises(AssertionError, Person.sqlmeta.addColumn, StringCol(name="expire"))
+        raises(AssertionError, Person.sqlmeta.addColumn, StringCol(name="set"))
+        raises(AssertionError, self._test_collidingName)
+
 ########################################
 ## Auto class generation
 ########################################
@@ -94,6 +107,19 @@ class TestAuto:
     )
     """
 
+    sqliteCreate = """
+    CREATE TABLE auto_test (
+      auto_id INTEGER PRIMARY KEY AUTOINCREMENT ,
+      first_name VARCHAR(100),
+      last_name VARCHAR(200) NOT NULL,
+      age INT DEFAULT NULL,
+      created DATETIME NOT NULL,
+      happy char(1) DEFAULT 'Y' NOT NULL,
+      long_field TEXT,
+      wannahavefun INT DEFAULT 0 NOT NULL
+    )
+    """
+
     sybaseCreate = """
     CREATE TABLE auto_test (
       auto_id integer,
@@ -128,11 +154,7 @@ class TestAuto:
     DROP TABLE auto_test
     """
 
-    sybaseDrop = """
-    DROP TABLE auto_test
-    """
-
-    mssqlDrop = sybaseDrop
+    sqliteDrop = sybaseDrop = mssqlDrop = postgresDrop
 
     def setup_method(self, meth):
         conn = getConnection()
@@ -149,8 +171,6 @@ class TestAuto:
             conn.query(dropper)
 
     def test_classCreate(self):
-        if not supports('fromDatabase'):
-            return
         class AutoTest(SQLObject):
             _connection = getConnection()
             class sqlmeta(sqlmeta):
